import type { CacheAdapter } from "@mikro-orm/core";
import type { Redis, RedisOptions } from "ioredis";
export interface BaseOptions {
    expiration?: number;
    keyPrefix?: string;
    debug?: boolean;
}
export interface BuildOptions extends BaseOptions, RedisOptions {
}
export interface ClientOptions extends BaseOptions {
    client: Redis;
    logger: (...args: unknown[]) => void;
}
export declare type RedisCacheAdapterOptions = BuildOptions | ClientOptions;
export declare class RedisCacheAdapter implements CacheAdapter {
    private readonly client;
    private readonly debug;
    private readonly expiration?;
    private readonly keyPrefix;
    private readonly logger;
    constructor(options: RedisCacheAdapterOptions);
    private computeKeyPrefix;
    private createRedisClient;
    private logDebugMessage;
    _getKey(name: string): string;
    get<T = any>(key: string): Promise<T | undefined>;
    set(key: string, data: any, _origin: string, expiration?: number | undefined): Promise<void>;
    remove(name: string): Promise<void>;
    clear(): Promise<void>;
    close(): Promise<void>;
}
export default RedisCacheAdapter;
